package org.gnu.glade;

import java.lang.reflect.Method;

import org.gnu.gtk.event.TextBufferEvent;
import org.gnu.gtk.event.TextBufferListener;

/**
 * TextBufferListener delegate class.
 * 
 * @author Tom Ball
 */
class TextBufferDelegate extends ListenerDelegate implements TextBufferListener {

    public TextBufferDelegate(String signal, Object owner, Method handler,
            Object target) throws NoSuchMethodException {
        super(signal, owner, handler, target);
    }

    public void textBufferEvent(TextBufferEvent event) {
        fireEvent(event);
    }
}
